@@ -13,6 +13,9 @@ CITYMAPPER_MOBILITY_TEMPLATE = "https://cdn.citymapper.com/data/cmi/Citymapper_M
 OPEN_COVID19_GROUP_REPO = "https://github.com/beoutbreakprepared/nCoV2019/archive/master.zip"
 CDC_DEATHS_BY_RACE_ETHNICITY_AGE_STATE = "https://data.cdc.gov/api/views/ks3g-spdg/rows.csv?accessType=DOWNLOAD"
 SEROSURVEY_SUPPLEMENTAL_DATA = '/home/j/Project/covid/data_intake/serology/supplemental_serosurvey_metadata'
+US_SYMPTOM_SURVEY_DATA = '/home/j/Project/covid/data_intake/symptom_survey/us'
+GLOBAL_SYMPTOM_SURVEY_DATA = '/home/j/Project/covid/data_intake/symptom_survey/global'
+PULSE_SURVEY_DATA = '/home/j/Project/covid/data_intake/pulse_survey/US Census_pulse surveys'
 
 # Shared paths
 EXEC_R_SCRIPT_PATH = Path('/share/singularity-images/lbd/shells/singR.sh')
@@ -64,6 +67,11 @@ ONEDRIVE_OUTPUT_DIR_NAME = Path('covid_onedrive')
 OPEN_COVID19_OUTPUT_DIR_NAME = Path('open_covid19_working_group')
 SEROSURVEY_OUTPUT_DIR_NAME = Path('serosurvey_data')
 SEROSURVEY_SUPPLEMENTAL_OUTPUT_DIR_NAME = Path('supplemental_serosurvey_metadata')
+SYMPTOM_SURVEY_OUTPUT_DIR_NAME = Path('symptom_survey')
+US_SYMPTOM_SURVEY_OUTPUT_DIR_NAME = Path('us')
+GLOBAL_SYMPTOM_SURVEY_OUTPUT_DIR_NAME = Path('global')
+PULSE_SURVEY_OUTPUT_DIR_NAME = Path('pulse_survey')
+PULSE_SURVEY_US_CENSUS_OUTPUT_DIR_NAME = Path('US Census_pulse surveys')
 
 LOG_DIR = Path("logs")
 LOG_FILE_NAME = Path("master_log.txt")
